//
// SSCheckBoxMatrix.java: Class file for WO Component 'SSCheckBoxMatrix'
// Project SwitchableString52
//
// Created by psuh on Tue Sep 09 2003
//
package com.goodeast.webobjects.switchablestring;


import com.webobjects.foundation.*;
import com.webobjects.appserver.*;
import com.webobjects.woextensions.*;
import java.util.*;


/**
    SwitchableString replacement for WOCheckboxMatrix. Most of the work is done by the code
    in the SSHelper class. 
*/
public class SSCheckboxMatrix extends WOCheckboxMatrix implements SSHelper.Callbacks {

    /**
        The bindings that are used by this class. Unlike most of the SwitchableString
        elements, this is the complete list of bindings. 
    */
    protected static NSArray _myAssociations = new NSArray( new String[] { "editable", "allowedTags", "disallowedTags", "list", "item", "selections", "maxColumns" } );

    protected NSDictionary _associationsDict;

    /**
        Since WOCheckboxMatrix is a subclass of WOComponent, not of WODynamicElement, it 
        doesn't receive a dictionary full of WOAssociation in the constructor. Therefore, we 
        need to explicitly create the associations dictionary, using SSParentAssociations. 
    */
    public SSCheckboxMatrix( WOContext context ) {

        super( context );

        NSMutableDictionary associationsBuilder = new NSMutableDictionary();

        Enumeration e = _myAssociations.objectEnumerator();
        while ( e.hasMoreElements() ) {

            String associationName = (String) e.nextElement();

            associationsBuilder.setObjectForKey( new SSParentAssociation( associationName ), associationName );
        }
        _associationsDict = associationsBuilder.immutableClone();
    }


    public void appendToResponse( WOResponse r, WOContext c ) {

        SSHelper.performAppendToResponse( r, c, _associationsDict, this );
    }

    public void takeValuesFromRequest( WORequest r, WOContext c ) {

        SSHelper.performTakeValuesFromRequest( r, c, _associationsDict, this );

    }

    public void callSuperAppendToResponse( WOResponse r, WOContext c ) {
        super.appendToResponse( r, c );
    }

    public void callSuperTakeValuesFromRequest( WORequest r, WOContext c ) {
        super.takeValuesFromRequest( r, c );
    }

}
